..
    This file is part of Python smosaic package.
    Copyright (C) 2025 INPE.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <https://www.gnu.org/licenses/gpl-3.0.html>.


====================================================================================
Simple python package for creating satellite image mosaics based on Brazil Data Cube
====================================================================================


.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
        :target: https://github.com/GSansigolo/smosaic/blob/master/LICENSE
        :alt: Software License

.. image:: https://img.shields.io/badge/lifecycle-stable-green.svg
        :target: https://www.tidyverse.org/lifecycle/#stable
        :alt: Software Life Cycle


.. image:: https://img.shields.io/github/tag/GSansigolo/smosaic.svg
        :target: https://github.com/GSansigolo/smosaic/releases
        :alt: Release


.. image:: https://img.shields.io/pypi/v/smosaic
        :target: https://pypi.org/project/smosaic/
        :alt: Python Package Index


.. image:: https://img.shields.io/discord/689541907621085198?logo=discord&logoColor=ffffff&color=7389D8
        :target: https://discord.com/channels/689541907621085198#
        :alt: Join us at Discord


About
=====

Simple python package for creating satellite image mosaics based on Brazil Data Cube


Installation
============

See `INSTALL.rst <./INSTALL.rst>`_


Changes
=======

See `CHANGES.rst <./CHANGES.rst>`_


Using WLTS in the Command Line
==============================

See `CLI.rst <./CLI.rst>`_.


Documentation
=============


WIP


References
==========


WIP


License
=======


.. admonition::
    Copyright (C) 2025 INPE.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
